==> hoteldruid-mod-bg_2.2.0-1.zip: bg/modifica_ospiti.php <==
<?php

switch ($messaggio) {

case "Modifica gli ospiti della prenotazione":	$messaggio = "Редактирайте гости на резервация"; break;
case "Cliente titolare":  			$messaggio = "Титулярен клиент"; break;
case "Ospite della prenotazione":  		$messaggio = "Гост на резервацията"; break;
case "nato il":  				$messaggio = "роден на"; break;
case "nata il":  				$messaggio = "роден на"; break;
case "CAP":  					$messaggio = "пощенски код"; break;
case "Telefono":  				$messaggio = "Телефон"; break;
case "2º telefono":  				$messaggio = "Втори телефон"; break;
case "3º telefono":  				$messaggio = "Трети телефон"; break;
case "Cognome":  				$messaggio = "Фамилия"; break;
case "nome":  					$messaggio = "име"; break;
case "sesso":  					$messaggio = "пол"; break;
case "Data di nascita":  			$messaggio = "Рожден ден"; break;
case "anno con 4 cifre":  			$messaggio = "година с 4 цифри"; break;
case "Documento":  				$messaggio = "Документ"; break;
case "scadenza":  				$messaggio = "валиден до"; break;
case "Altri ospiti":  				$messaggio = "Други гости"; break;
case "Modifica gli ospiti":  			$messaggio = "Променете гости"; break;
case "Torna indietro":  			$messaggio = "Обратно"; break;
case "Gli ospiti della prenotazione":  		$messaggio = "Гостите на резервацията"; break;
case "sono stati modificati":  			$messaggio = "бяха променени"; break;
case "nato":  					$messaggio = "роден"; break;
case "nata":  					$messaggio = "роден"; break;
case "il":  					$messaggio = "на"; break;
case " a":  					$messaggio = " в"; break;
case "scade":  					$messaggio = "изтича на"; break;
case "cittadinanza":  				$messaggio = "националност"; break;
case "città di nascita":  			$messaggio = "град по месторождение"; break;
case "reg./prov. di nascita":  			$messaggio = "област по месторождение"; break;
case "nazione di nascita":  			$messaggio = "нация по месторождение"; break;
case "nazione":  				$messaggio = "нация"; break;
case "rilasciato da":  				$messaggio = "издаден от"; break;
case "nazione di rilascio":  			$messaggio = "държава издател"; break;
case "Ospite principale":  			$messaggio = "Основен гост"; break;
case "Parentela":  				$messaggio = "Свързаност"; break;
case "parentela":  				$messaggio = "свързаност"; break;
case "Codice fiscale":  			$messaggio = "Фискален код"; break;
case "ln.":  					$messaggio = "ln."; break;
case "reg./prov.":  				$messaggio = "region"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "città":  					$messaggio = "city"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "Modifica gli ospiti delle prenotazioni":	$messaggio = "Modify guests of reservations"; break;
case "della prenotazione":  			$messaggio = "of reservation"; break;
case "Gli ospiti delle prenotazioni":  		$messaggio = "The guests of reservations"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-bg_3.0.8-1.zip: bg/modifica_ospiti.php <==
<?php

switch ($messaggio) {

case "Modifica gli ospiti della prenotazione":	$messaggio = "Редактирайте гости на резервация"; break;
case "Cliente titolare":  			$messaggio = "Титулярен клиент"; break;
case "Ospite della prenotazione":  		$messaggio = "Гост на резервацията"; break;
case "nato il":  				$messaggio = "роден на"; break;
case "nata il":  				$messaggio = "роден на"; break;
case "CAP":  					$messaggio = "пощенски код"; break;
case "Telefono":  				$messaggio = "Телефон"; break;
case "2º telefono":  				$messaggio = "Втори телефон"; break;
case "3º telefono":  				$messaggio = "Трети телефон"; break;
case "Cognome":  				$messaggio = "Фамилия"; break;
case "nome":  					$messaggio = "име"; break;
case "sesso":  					$messaggio = "пол"; break;
case "Data di nascita":  			$messaggio = "Рожден ден"; break;
case "anno con 4 cifre":  			$messaggio = "година с 4 цифри"; break;
case "Documento":  				$messaggio = "Документ"; break;
case "scadenza":  				$messaggio = "валиден до"; break;
case "Altri ospiti":  				$messaggio = "Други гости"; break;
case "Modifica gli ospiti":  			$messaggio = "Променете гости"; break;
case "Torna indietro":  			$messaggio = "Обратно"; break;
case "Gli ospiti della prenotazione":  		$messaggio = "Гостите на резервацията"; break;
case "sono stati modificati":  			$messaggio = "бяха променени"; break;
case "nato":  					$messaggio = "роден"; break;
case "nata":  					$messaggio = "роден"; break;
case "il":  					$messaggio = "на"; break;
case " a":  					$messaggio = " в"; break;
case "scade":  					$messaggio = "изтича на"; break;
case "cittadinanza":  				$messaggio = "националност"; break;
case "città di nascita":  			$messaggio = "град по месторождение"; break;
case "reg./prov. di nascita":  			$messaggio = "област по месторождение"; break;
case "nazione di nascita":  			$messaggio = "нация по месторождение"; break;
case "nazione":  				$messaggio = "нация"; break;
case "rilasciato da":  				$messaggio = "издаден от"; break;
case "nazione di rilascio":  			$messaggio = "държава издател"; break;
case "Ospite principale":  			$messaggio = "Основен гост"; break;
case "Parentela":  				$messaggio = "Свързаност"; break;
case "parentela":  				$messaggio = "свързаност"; break;
case "Codice fiscale":  			$messaggio = "Фискален код"; break;
case "ln.":  					$messaggio = "ln."; break;
case "Modifica Ospiti":  			$messaggio = "Modify Guests"; break;
case "reg./prov.":  				$messaggio = "region"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "città":  					$messaggio = "city"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "Modifica gli ospiti delle prenotazioni":	$messaggio = "Modify guests of reservations"; break;
case "della prenotazione":  			$messaggio = "of reservation"; break;
case "Gli ospiti delle prenotazioni":  		$messaggio = "The guests of reservations"; break;
case "email":  					$messaggio = "email"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC/codice":  				$messaggio = "certified email"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
